<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

function getActivePaymentGateways($conn) {
    $stmt = $conn->prepare("SELECT * FROM payment_gateways WHERE status = 'Active'");
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

if (isset($_GET['package_id']) && isset($_GET['billing_cycle'])) {
    $package_id = intval($_GET['package_id']);
    $billing_cycle = $_GET['billing_cycle'];

    // Fetch package details
    $stmt = $conn->prepare("SELECT * FROM packages WHERE id = ?");
    $stmt->execute([$package_id]);
    $package = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$package) {
        header("Location: packages.php");
        exit();
    }

    // Adjust price based on billing cycle
    $package_price = $billing_cycle == 'yearly' ? $package['yearly_price'] : $package['monthly_price'];
} else {
    header("Location: packages.php");
    exit();
}

$payment_gateways = getActivePaymentGateways($conn);

$pageTitle = "Checkout";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Checkout</h1>
            <div class="row justify-content-center">
                <div class="col-lg-6">
                    <div class="card shadow mb-4">
                        <div class="card-header py-3">
                            <h6 class="m-0 font-weight-bold text-primary">Confirm Your Package</h6>
                        </div>
                        <div class="card-body">
                            <p>Package: <strong><?php echo htmlspecialchars($package['name']); ?></strong></p>
                            <p>Website Limit: <strong><?php echo $package['website_limit'] == -1 ? 'Unlimited' : htmlspecialchars($package['website_limit']); ?></strong></p>
                            <p>Bandwidth Limit: <strong><?php echo htmlspecialchars($package['bandwidth_limit']); ?> GB</strong></p>
                            <ul class="list-unstyled">
                                <?php 
                                $features = explode("\n", $package['features']);
                                foreach ($features as $feature) {
                                    echo "<li><strong>" . htmlspecialchars($feature) . "</strong></li>";
                                }
                                ?>
                            </ul>
                            <p>Price: <strong>$<?php echo htmlspecialchars($package_price); ?> / <?php echo htmlspecialchars($billing_cycle == 'yearly' ? 'yr' : 'mo'); ?></strong></p>
                            <form method="post" action="process_payment.php">
                                <input type="hidden" name="package_id" value="<?php echo $package_id; ?>">
                                <input type="hidden" name="billing_cycle" value="<?php echo htmlspecialchars($billing_cycle); ?>">
                                <div class="form-group">
                                    <label for="gateway_name">Payment Method</label>
                                    <select name="gateway_name" id="gateway_name" class="form-control form-control-sm" required>
                                        <?php foreach ($payment_gateways as $gateway): ?>
                                            <option value="<?php echo htmlspecialchars($gateway['name']); ?>"><?php echo htmlspecialchars($gateway['name']); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <button type="submit" class="btn btn-primary btn-block">Proceed to Payment</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
