<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$pageTitle = "Invoices";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

// Fetch invoices for the logged-in user
$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT invoices.*, packages.name AS package_name FROM invoices 
                        JOIN subscriptions ON invoices.subscription_id = subscriptions.id 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE invoices.user_id = ?");
$stmt->execute([$user_id]);
$invoices = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Invoices</h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Your Invoices</h6>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Status</th>
                                    <th>Date</th>
                                    <th>Package</th>
                                    <th>Amount</th>
                                    <th>Gateway</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                foreach ($invoices as $invoice) {
                                    $formattedDate = date('d-M-Y', strtotime($invoice['created_at']));
                                    $statusClass = $invoice['status'] === 'Paid' ? 'text-success font-weight-bold' : 'text-danger font-weight-bold';
                                    echo "<tr>";
                                    echo "<td>" . htmlspecialchars($invoice['id']) . "</td>";
                                    echo "<td class='$statusClass'>" . htmlspecialchars($invoice['status']) . "</td>";
                                    echo "<td>" . $formattedDate . "</td>";
                                    echo "<td>" . htmlspecialchars($invoice['package_name']) . "</td>";
                                    echo "<td>$" . htmlspecialchars($invoice['amount']) . "</td>";
                                    echo "<td>" . htmlspecialchars($invoice['gateway_name']) . "</td>";
                                    echo "</tr>";
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
