<?php
require '../../stripe/init.php'; // Ensure this path is correct
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$stripe_secret_key = get_api_setting('stripe_secret_key');
\Stripe\Stripe::setApiKey($stripe_secret_key);

if (!isset($_SESSION['payment_data'])) {
    header("Location: packages.php");
    exit();
}

$payment_data = $_SESSION['payment_data'];
$success_url = (isset($_SERVER['HTTPS']) ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . "/pages/user/payment_success.php?session_id={CHECKOUT_SESSION_ID}";
$cancel_url = (isset($_SERVER['HTTPS']) ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . "/pages/user/payment_cancel.php";

try {
    $session = \Stripe\Checkout\Session::create([
        'payment_method_types' => ['card'],
        'line_items' => [[
            'price_data' => [
                'currency' => 'usd',
                'product_data' => [
                    'name' => $payment_data['package_name'],
                ],
                'unit_amount' => $payment_data['package_price'] * 100,
            ],
            'quantity' => 1,
        ]],
        'mode' => 'payment',
        'client_reference_id' => $payment_data['user_id'],
        'metadata' => [
            'package_id' => $payment_data['package_id'],
            'gateway_name' => $payment_data['gateway_name'],
        ],
        'success_url' => $success_url,
        'cancel_url' => $cancel_url,
    ]);

    header("Location: " . $session->url);
    exit();
} catch (\Stripe\Exception\ApiErrorException $e) {
    echo 'Error: ' . $e->getMessage();
}
?>
