<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

if (!isset($_GET['id'])) {
    header('Location: view_tickets.php');
    exit();
}

$ticket_id = $_GET['id'];
$user_id = $_SESSION['user_id'];

// Fetch ticket details
$stmt = $conn->prepare("SELECT * FROM tickets WHERE ticket_id = ? AND user_id = ?");
$stmt->execute([$ticket_id, $user_id]);
$ticket = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$ticket) {
    header('Location: view_tickets.php');
    exit();
}

// Fetch ticket replies
$stmt = $conn->prepare("SELECT ticket_replies.*, users.name AS user_name, users.email AS user_email FROM ticket_replies 
                        JOIN users ON ticket_replies.user_id = users.id 
                        WHERE ticket_replies.ticket_id = ? ORDER BY ticket_replies.created_at ASC");
$stmt->execute([$ticket['id']]);
$replies = $stmt->fetchAll(PDO::FETCH_ASSOC);

$pageTitle = "View Ticket";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

function getGravatarUrl($email, $size = 200) {
    $emailHash = md5(strtolower(trim($email)));
    return "https://www.gravatar.com/avatar/$emailHash?s=$size";
}

function formatDate($datetime) {
    $date = new DateTime($datetime);
    return $date->format('d-M-Y h:i A');
}
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Ticket: <?php echo htmlspecialchars($ticket['subject']); ?></h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Ticket Details</h6>
                </div>
                <div class="card-body">
                    <p><strong>Status:</strong> <?php echo htmlspecialchars($ticket['status']); ?></p>
                    <p><strong>Created At:</strong> <?php echo formatDate($ticket['created_at']); ?></p>
                    <hr>
                    <h6 class="font-weight-bold">Messages</h6>
                    <?php foreach ($replies as $reply): ?>
                        <div class="card mb-4">
                            <div class="card-body">
                                <div class="d-flex align-items-center mb-3">
                                    <img class="img-profile rounded-circle mr-2" src="<?php echo getGravatarUrl($reply['user_email'], 40); ?>" alt="Profile Image">
                                    <strong><?php echo htmlspecialchars($reply['user_name']); ?>:</strong>
                                </div>
                                <p><?php echo nl2br(htmlspecialchars($reply['message'])); ?></p>
                                <small class="text-muted"><?php echo formatDate($reply['created_at']); ?></small>
                            </div>
                        </div>
                    <?php endforeach; ?>
                    <hr>
                    <form method="post" action="reply_ticket.php">
                        <input type="hidden" name="ticket_id" value="<?php echo htmlspecialchars($ticket['ticket_id']); ?>">
                        <div class="form-group">
                            <label for="message">Reply</label>
                            <textarea class="form-control" id="message" name="message" rows="4" required></textarea>
                        </div>
                        <button type="submit" class="btn btn-primary">Submit Reply</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
